<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
// Add client Collection section
$wp_customize->add_section( 'educollege_pro_client_section', array(
    'title'             => esc_html__( 'Client','educollege-pro' ),
    'description'       => esc_html__( 'Client Section options.', 'educollege-pro' ),
    'panel'             => 'educollege_pro_front_page_panel',
    'active_callback'   => 'educollege_pro_is_client_section_panel_enable',
) );

// client content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[client_section_enable]', array(
    'default'           =>  $options['client_section_enable'],
    'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[client_section_enable]', array(
    'label'             => esc_html__( 'Client Section Enable', 'educollege-pro' ),
    'section'           => 'educollege_pro_client_section',
    'on_off_label'      => educollege_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'educollege_pro_theme_options[client_count]', array(
    'default'           => $options['client_count'],
    'sanitize_callback' => 'educollege_pro_sanitize_number_range',
    'validate_callback' => 'educollege_pro_validate_client_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[client_count]', array(
    'label'             => esc_html__( 'Number of client', 'educollege-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
    'section'           => 'educollege_pro_client_section',
    'active_callback'   => 'educollege_pro_is_client_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'educollege_pro_theme_options[client_content_type]', array(
    'default'           => $options['client_content_type'],
    'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[client_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
    'section'           => 'educollege_pro_client_section',
    'type'              => 'select',
    'active_callback'   => 'educollege_pro_is_client_section_enable',
    'choices'           => array( 
        'page'          => esc_html__( 'Page', 'educollege-pro' ),
        'post'          => esc_html__( 'Post', 'educollege-pro' ),
        'category'          => esc_html__( 'Category', 'educollege-pro' ),
        'custom'        => esc_html__( 'Custom', 'educollege-pro' ),
    ),
) );

for ($i=1; $i <= $options['client_count'] ; $i++) :
    // client pages drop down chooser control and setting
    $wp_customize->add_setting( 'educollege_pro_theme_options[client_content_page_' . $i . ']', array(
        'sanitize_callback' => 'educollege_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[client_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
        'section'           => 'educollege_pro_client_section',
        'choices'           => educollege_pro_page_choices(),
        'active_callback'   => 'educollege_pro_is_client_section_content_page_enable',
    ) ) );

    // client posts drop down chooser control and setting
    $wp_customize->add_setting( 'educollege_pro_theme_options[client_content_post_' . $i . ']', array(
        'sanitize_callback' => 'educollege_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[client_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
        'section'           => 'educollege_pro_client_section',
        'choices'           => educollege_pro_post_choices(),
        'active_callback'   => 'educollege_pro_is_client_section_content_post_enable',
    ) ) );

    $wp_customize->add_setting( 'educollege_pro_theme_options[client_image_' . $i . ']', array(
        'sanitize_callback' => 'educollege_pro_sanitize_image',
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[client_image_' . $i . ']',
            array(
            'label'             => sprintf( esc_html__( 'Client Logo %d', 'educollege-pro' ), $i ),
            'section'           => 'educollege_pro_client_section',
            'active_callback'   => 'educollege_pro_is_client_section_content_custom_enable',
    ) ) );

    $wp_customize->add_setting( 'educollege_pro_theme_options[client_url_' . $i . ']', array(
        'sanitize_callback' => 'esc_url_raw',
    ) );

    $wp_customize->add_control( 'educollege_pro_theme_options[client_url_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Client Url %d', 'educollege-pro' ), $i ),
        'section'           => 'educollege_pro_client_section',
        'active_callback'   => 'educollege_pro_is_client_section_content_custom_enable',
        'type'              => 'url',
    ) );


    $wp_customize->add_setting( 'educollege_pro_theme_options[client_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[client_hr_'. $i .']',
        array(
            'section'           => 'educollege_pro_client_section',
            'active_callback'   => 'educollege_pro_is_client_section_enable',
            'type'            => 'hr'
    ) ) );

endfor;

$wp_customize->add_setting(  'educollege_pro_theme_options[client_content_category]', array(
    'sanitize_callback' => 'educollege_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[client_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'educollege-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
    'section'           => 'educollege_pro_client_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'educollege_pro_is_client_section_content_category_enable'
) ) );



        