<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'educollege_pro_cta_section', array(
    'title'             => esc_html__( 'Call To Action','educollege-pro' ),
    'description'       => esc_html__( 'Call To Action Section options.', 'educollege-pro' ),
    'panel'             => 'educollege_pro_front_page_panel',
    'active_callback'   => 'educollege_pro_is_cta_section_panel_enable',
) );

// Call To Action content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_section_enable]', array(
    'default'           =>  $options['cta_section_enable'],
    'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[cta_section_enable]', array(
    'label'             => esc_html__( 'Call To Action Section Enable', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'on_off_label'      => educollege_pro_switch_options(),
) ) );

// Call To Action content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_content_type]', array(
    'default'           => $options['cta_content_type'],
    'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'type'              => 'select',
    'active_callback'   => 'educollege_pro_is_cta_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'educollege-pro' ),
        'post'      => esc_html__( 'Post', 'educollege-pro' ),
        'custom'    => esc_html__( 'Custom', 'educollege-pro' ),
    ),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'educollege_pro_sanitize_page',
) );

$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'choices'           => educollege_pro_page_choices(),
    'active_callback'   => 'educollege_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'educollege_pro_sanitize_page',
) );

$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select Post', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'choices'           => educollege_pro_post_choices(),
    'active_callback'   => 'educollege_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['cta_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[cta_title]', array(
    'label'             => esc_html__( 'Title', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'active_callback'   => 'educollege_pro_is_cta_section_content_custom_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[cta_title]', array(
        'selector'            => '#call-to-action .wrapper .entry-header h2',
        'settings'            => 'educollege_pro_theme_options[cta_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'educollege_pro_cta_title_partial',
    ) );
}

// cta title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_content]', array(
    'sanitize_callback' => 'wp_kses_post',
    'default'           => $options['cta_content'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[cta_content]', array(
    'label'             => esc_html__( 'Content', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'active_callback'   => 'educollege_pro_is_cta_section_content_custom_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[cta_content]', array(
        'selector'            => '#call-to-action .wrapper .entry-content p',
        'settings'            => 'educollege_pro_theme_options[cta_content]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'educollege_pro_cta_content_partial',
    ) );
}

// video link setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[video_link]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[video_link]', array(
    'label'             => esc_html__( 'Video Link', 'educollege-pro' ),
    'section'           => 'educollege_pro_cta_section',
    'active_callback'   => 'educollege_pro_is_cta_section_enable',
    'type'              => 'url',
) );

// cta image setting and control.
$wp_customize->add_setting( 'educollege_pro_theme_options[cta_image]', array(
    'sanitize_callback' => 'educollege_pro_sanitize_image',
    'default'           =>  $options['cta_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[cta_image]',
    array(
    'label'             => esc_html__( 'Background Image ', 'educollege-pro' ), 
    'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'educollege-pro' ), 700, 600 ),
    'section'           => 'educollege_pro_cta_section',
    'active_callback'   => 'educollege_pro_is_cta_section_enable',
) ) );

