<?php
/**
 * Courses section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
if ( ! function_exists( 'educollege_pro_add_course_section' ) ) :
    /**
    * Add course section
    *
    *@since educollege Pro 1.0.0
    */
    function educollege_pro_add_course_section() {
    	$options = educollege_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $course_enable = apply_filters( 'educollege_pro_section_status', true, 'course_section_enable' );

        if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'second-design'){
            $course_enable = false;
        }

        if ( true !== $course_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'educollege_pro_filter_course_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render course section now.
        educollege_pro_render_course_section( $section_details );
    }
endif;

if ( ! function_exists( 'educollege_pro_get_course_section_details' ) ) :
    /**
    * course section details.
    *
    * @since educollege Pro 1.0.0
    * @param array $input course section details.
    */
    function educollege_pro_get_course_section_details( $input ) {
        $options = educollege_pro_get_theme_options();

        // Content type.
        $course_content_type  = $options['course_content_type'];
        $course_count = ! empty( $options['course_count'] ) ? $options['course_count'] : 4;
        
        $content = array();
        switch ( $course_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_page_' . $i] ) ) :
                        $page_ids[] = $options['course_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_post_' . $i] ) ) :
                        $post_ids[] = $options['course_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['course_content_category'] ) ? $options['course_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $course_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'course':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $course_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_course_' . $i] ) ) :
                        $course_ids[] = $options['course_content_course_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-course',
                    'post__in'          => ( array ) $course_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    ); 

            break;

            case 'course-category':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $cat_id = ! empty( $options['course_content_course_category'] ) ? $options['course_content_course_category'] : '';

                $args = array(
                    'post_type'         => 'tp-course',
                    'posts_per_page'    => absint( $course_count ),
                    'tax_query'         => array(  
                        array( 
                            'taxonomy'  => 'tp-course-category', 
                            'field'     => 'id', 
                            'terms'     => array( $cat_id ),  
                            ) 
                        ),
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 0;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = educollege_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'educollege_pro_filter_course_section_details', 'educollege_pro_get_course_section_details' );


if ( ! function_exists( 'educollege_pro_render_course_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_course_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-courses" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <?php if ( ! empty( $options['course_title'] ) ): ?>
                            <h2 class="section-title">
                                <?php echo esc_html( $options['course_title'] ) ; ?>
                            </h2>
                        <?php endif ?>
                        <?php if ( ! empty( $options['course_sub_title'] ) ): ?>
                            <p class="section-subtitle">
                                <?php echo esc_html( $options['course_sub_title'] ) ; ?>
                            </p>
                        <?php endif ?>

                    </div><!-- .section-header -->

                    <div class="col-2 clear">
                        <?php foreach ( $content_details as $content ): ?>
                            <article class="has-post-thumbnail">
                                <div class="featured-course-item">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                                        <div class="overlay"></div>
                                        <?php if ( ! empty( $options['course_read_more'] ) ): ?>
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="more-link">
                                                <?php echo esc_html( $options['course_read_more'] ) ; ?>
                                            </a>
                                        <?php endif ?>
                                        
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title">
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                    <?php echo esc_html( $content['title'] ) ; ?>
                                                </a>
                                            </h2>
                                        </header>

                                        <div class="entry-content">
                                            <p>
                                                <?php echo esc_html( $content['excerpt'] ) ; ?>
                                            </p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->

                                    <div class="clear"></div>
                                    <?php if ( ! in_array( $options['course_content_type'] , array('post', 'page', 'category') ) ): 
                                        ?>
                                        <ul class="tp-education-meta entry-meta">
                                            <li>
                                                <?php tp_course_duration( $content['id'] ) ; ?>
                                            </li>
                                            <li>
                                                <?php tp_course_professor( $content['id'] ) ; ?>
                                            </li>
                                            <li>
                                                <?php tp_course_students( $content['id'] ) ; ?>
                                            </li>
                                        </ul>
                                    <?php endif ?>
                                </div><!-- .featured-course-item -->
                            </article>
                        <?php endforeach ?>
                        
                    </div><!-- .col-2 -->
                    <?php if ( ! empty( $options['course_btn_title'] ) ): 
                        $url = ! empty( $options['course_btn_link'] ) ? $options['course_btn_link'] : '#' ;
                        ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( $url ) ; ?>" class="btn">
                                <?php echo esc_html( $options['course_btn_title'] ) ?>
                            </a>
                        </div><!-- .view-all -->
                    <?php endif ?>
                    
                </div><!-- .wrapper -->
            </div><!-- #featured-courses -->

    <?php }
endif;