<?php
/**
 * Featured section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
if ( ! function_exists( 'educollege_pro_add_featured_section' ) ) :
    /**
    * Add Featured section
    *
    *@since educollege Pro 1.0.0
    */
    function educollege_pro_add_featured_section() {
    	$options = educollege_pro_get_theme_options();
        // Check if Featured is enabled on frontpage
        $featured_enable = apply_filters( 'educollege_pro_section_status', true, 'featured_section_enable' );

        // featured section is enable only on third and fifth design
        if( $options['home_layout'] != 'third-design' && $options['home_layout'] != 'fifth-design'){
            $featured_enable = false;
        }

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get Featured section details
        $section_details = array();
        $section_details = apply_filters( 'educollege_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        switch ( $options['home_layout'] ) {
            case 'third-design':
                // Render Featured section now.
                educollege_pro_render_featured_section( $section_details );
                break;
            
            case 'fifth-design':
                // Render Featured section now.
                educollege_pro_render_featured_medical_section( $section_details );
                break;
            
            default:
                educollege_pro_render_featured_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'educollege_pro_get_featured_section_details' ) ) :
    /**
    * Featured section details.
    *
    * @since educollege Pro 1.0.0
    * @param array $input Featured section details.
    */
    function educollege_pro_get_featured_section_details( $input ) {
        $options = educollege_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 3;
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = educollege_pro_trim_content( 15 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnails' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'educollege_pro_filter_featured_section_details', 'educollege_pro_get_featured_section_details' );


if ( ! function_exists( 'educollege_pro_render_featured_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_featured_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="blog-featured-posts" class="relative page-section">
            <div class="wrapper">
                <div class="blog-section-content clear">
                <?php foreach ( $content_details as $content ): 
                    $category = get_the_category($content['id']); 
                    ?>
                    <article>
                        <div class="blog-featured-item" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <div class="entry-container">
                                <?php if ( $category[0] ) : ?>
                                <span class="cat-links">
                                    <a href="<?php echo esc_url(get_category_link( $category[0]->term_id )) ; ?>"><?php echo esc_html($category[0]->cat_name); ?></a>                                    
                                </span><!-- .cat-links -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                        <?php echo esc_html( $content['title'] ) ; ?>
                                    </a>    
                                </header>
                                <?php educollege_pro_posted_on($content['id']); ?>
                            </div><!-- .entry-container -->
                        </div><!-- .blog-featured-item -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .blog-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #blog-featured-posts -->

    <?php }
endif;
if ( ! function_exists( 'educollege_pro_render_featured_medical_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_featured_medical_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];
        $featured_title = ! empty( $options['featured_title'] ) ? $options['featured_title'] : esc_html__( 'Our Features', 'educollege-pro' );
        $featured_description = ! empty( $options['featured_description'] ) ? $options['featured_description'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="medical-features" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $featured_title ); ?></h2>
                        <p class="section-subtitle"><?php echo wp_kses_post($featured_description); ?></p>
                    </div>
                    <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $i => $content ):  
                        $icon = (isset($options['featured_content_icon_' . ($i+1)])) ? $options['featured_content_icon_' . ($i+1)] :  $options['featured_content_icon'];
                        ?>
                        <article>
                            <div class="medical-feature-item" style="background-image: url('<?php echo esc_url(get_template_directory_uri().'/assets/uploads/medical-feature-item-bg.png'); ?>');">
                                <div class="feature-icon">
                                    <a href="#"><i class="fa <?php echo esc_attr($icon)?>"></i></a>
                                </div><!-- .feature-icon -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .medical-feature-item -->
                        </article>
                    <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-features -->

    <?php }
endif;