<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
if ( ! function_exists( 'educollege_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Educollege Pro 1.0.0
    */
    function educollege_pro_add_service_section() {
    	$options = educollege_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'educollege_pro_section_status', true, 'service_section_enable' );

        if( $options['home_layout'] == 'third-design'){
            $service_enable = false;
        }

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'educollege_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render services section now.
                educollege_pro_render_service_section( $section_details );
                break;
            
            case 'fifth-design':
                // Render services section now.
                educollege_pro_render_service_medical_section( $section_details );
                break;
            
            default:
                educollege_pro_render_service_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'educollege_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Educollege Pro 1.0.0
    * @param array $input service section details.
    */
    function educollege_pro_get_service_section_details( $input ) {
        $options = educollege_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count = ! empty( $options['service_count'] ) ? $options['service_count'] : 3;
        
        $content = array();
        switch ( $service_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = educollege_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnails' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'educollege_pro_filter_service_section_details', 'educollege_pro_get_service_section_details' );


if ( ! function_exists( 'educollege_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_service_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-services" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['service_title'] ) ): ?>
                        <h2 class="section-title">
                            <?php echo esc_html( $options['service_title'] ) ; ?>
                        </h2>
                    <?php endif;

                    if ( ! empty( $options['service_sub_title'] ) ): ?>
                        <p class="section-subtitle">
                             <?php echo esc_html( $options['service_sub_title'] ) ; ?>
                        </p>
                    <?php endif ?>
                    
                </div><!-- .section-header -->

                <div class="<?php echo esc_attr( $options['service_column_layout'] ); ?> clear">
                    <?php $i = 1 ; foreach ( $content_details as $content ): ?>
                        <article>
                            <div class="service-item-wrapper">
                                <div class="service-icon">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                        <i class="fa <?php echo esc_attr( $options['service_content_icon_' . $i] ) ; ?>"></i>
                                    </a>
                                </div><!-- .service-icon -->

                                <header class="entry-header">
                                    <h2 class="entry-title">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                            <?php echo esc_html( $content['title'] ) ; ?>
                                        </a>
                                    </h2>
                                </header>

                                <div class="entry-content">
                                    <p>
                                        <?php echo esc_html( $content['excerpt'] ) ; ?>
                                    </p>
                                </div><!-- .entry-content -->
                            </div><!-- .service-item-wrapper -->
                        </article>
                    <?php $i++ ; endforeach ?>
                </div><!-- .col-3 -->
            </div><!-- .wrapper -->
        </div><!-- #our-services -->
        
    <?php }
endif;
if ( ! function_exists( 'educollege_pro_render_service_medical_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_service_medical_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();

        if ( empty( $content_details ) )  return; ?>
        
        <div id="medical-services" class="relative page-section">
            <div class="wrapper">
                <div class="section-content <?php echo esc_attr( $options['service_column_layout'] ); ?> clear">
                    <?php foreach($content_details as $i => $content):?>
                    <article>
                        <div class="medical-service-item">
                            <div class="inner-box">
                                <?php if(has_post_thumbnail($content['id'])): ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>"><img src="<?php echo esc_url( $content['image'] ) ;?>" alt="medical-service-<?php echo $i; ?>"></a>
                                </div><!-- .featured-image -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                </header><!-- .entry-header -->
                            </div><!-- .inner-box -->
                        </div><!-- .medical-service-item -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #medical-services -->
        
    <?php }
endif;