<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */
if ( ! function_exists( 'educollege_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since educollege Pro 1.0.0
    */
    function educollege_pro_add_team_section() {
    	$options = educollege_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'educollege_pro_section_status', true, 'team_section_enable' );

        if( $options['home_layout'] != 'default-design'){
            $team_enable = false;
        }


        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'educollege_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        educollege_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'educollege_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since educollege Pro 1.0.0
    * @param array $input team section details.
    */
    function educollege_pro_get_team_section_details( $input ) {
        $options = educollege_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 5;
        
        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $team_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tp-team':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $team_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_team_' . $i] ) ) :
                        $team_ids[] = $options['team_content_team_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-team',
                    'post__in'          => ( array ) $team_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    ); 

            break;

            case 'tp-team-category':
                 if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }

                $cat_id = ! empty( $options['team_content_team_category'] ) ? $options['team_content_team_category'] : '';

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => absint( $team_count ),
                    'tax_query'         => array(  
                        array( 
                            'taxonomy'  => 'tp-team-category', 
                            'field'     => 'id', 
                            'terms'     => array( $cat_id ),  
                            ) 
                        ),
                    );  
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = educollege_pro_trim_content( 50 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'educollege_pro_filter_team_section_details', 'educollege_pro_get_team_section_details' );


if ( ! function_exists( 'educollege_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_team_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();
        $team_content_type  = $options['team_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-team" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <?php if ( $options['team_title'] ): ?>
                            <h2 class="section-title">
                                <?php echo esc_html( $options['team_title'] ) ; ?>
                            </h2>
                        <?php endif ?>
                        <?php if ( $options['team_sub_title'] ): ?>
                            <p class="section-subtitle">
                                <?php echo esc_html( $options['team_sub_title'] ) ; ?>
                            </p>
                        <?php endif ?>
                        
                    </div><!-- .section-header -->

                    <div class="team-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 500, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": true }'>
                        <?php foreach ( $content_details as $content ): ?>
                            <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                                <div class="entry-container">
                                <?php if ( ! in_array($team_content_type, array('post', 'page', 'category') ) ):
                                    educollege_pro_team_social( $content['id'] );
                                endif ; ?>
                                

                                    <header class="entry-header">
                                        <h2 class="entry-title">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                <?php echo esc_html( $content['title'] ) ; ?>
                                            </a>
                                        </h2>
                                        <?php if ( ! in_array($team_content_type, array('post', 'page', 'category') ) ): ?>
                                            <p class="position">
                                                <?php echo esc_html( get_post_meta( $content['id'], 'tp_team_designation_value', true ) ); ?>
                                            </p>
                                        <?php endif ?>                                    
                                    </header>

                                    <div class="entry-content">
                                        <p>
                                            <?php echo esc_html( $content['excerpt'] ) ; ?>
                                        </p>
                                    </div>
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach ?>
                        
                    </div><!-- .team-slider -->
                </div><!-- .wrapper -->

                <?php if ( $options['team_section_buttom_slider_enable'] == true ): ?>
                    <div class="team-slider-nav">
                        <?php foreach ( $content_details as $content ): ?>
                             <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                                </div>
                            </article>
                        <?php endforeach ?>                    
                    </div><!-- .team-slider-nav -->
                <?php endif ?>
            </div><!-- #our-team -->
    <?php }
endif;